Datagram

Struct Datagram 

pub struct Datagram { /* private fields */ }
Representation of a datagram

The total length is limited to 128 bits The bits of a telegram are internally enumerated from 0 to 127. A default datagram is expected to be empty (i.e. containing zero bits)

Implementations

Source

impl Datagram

pub fn len(&self) -> u8

pub fn is_empty(&self) -> bool

pub fn extract_data(&self, min: u8, max: u8) -> u128

Extract a data slice from the datagram

Args
  • min - start index (included)
  • max - max index (not included)
Returns

the extracted value

Panics

if 0 <= min < max <= len() is violated

Example

use manchester_code::Datagram;

let datagram = Datagram::new("0-111_10101_00001111");
assert_eq!(0b1111, datagram.extract_data(0, 4));
assert_eq!(0b1111, datagram.extract_data(0, 8));
assert_eq!(0b1111, datagram.extract_data(datagram.len()-5, datagram.len()));
pub fn new(bit_repr: &str) -> Self

Create a new datagram from “binary” string

Arguments
  • bit_repr - Bit representation as string of zeros and ones. Arbitrary delimiter signs (for readability) are ignored
Example
use manchester_code::Datagram;

let datagram = Datagram::new("0-111_10101_00001111");